@@ -2,6 +2,8 @@ from searcHPV.generate_alignment import *
 import subprocess
 from searcHPV.general import *
 
+from remillsscr.HPV_fusion.searcHPV.searcHPV.SearcHPV.searcHPV.generate_alignment import rm_inter_bam
+
 #####################
 #pipeline of alignment
 #Function:
@@ -12,10 +14,9 @@ from searcHPV.general import *
 #fq2: paired-end raw sequencing data, fastq2
 #humRef: human reference genome
 #outputDir: output directory
-#mkdup: = True: remove duplicate = False : don't remove duplicate, default = TRUE
 #multi: if fastq file is in gz format: default = True
 #index: if True, index the reference files; if False, not index the references files
-def alignment(fq1, fq2, humRef, virRef, outputDir, index, mkdup, gz):
+def alignment(fq1, fq2, humRef, virRef, outputDir, index, gz):
     #make output dir
     outputDir = os.path.abspath(outputDir)
     mkdir(outputDir)
@@ -32,11 +33,12 @@ def alignment(fq1, fq2, humRef, virRef, outputDir, index, mkdup, gz):
     generate_indel_alignment_bash(indelFile,ref,scriptDir)
     check_file(alignmentFile)
     check_file(indelFile)
-
-    #rmdup for alignment results
-    
     bashFile = scriptDir + f"/alignment.sh"
 
+    #remove intermediate file
+    rmInter = scriptDir + f"/rm_inter.sh"
+    rm_inter_bam(rmInter,scriptDir)
+
     if index:
         #index humRef and virRef
         indexFileHum = scriptDir + "/index_hum.sh"
@@ -50,47 +52,31 @@ def alignment(fq1, fq2, humRef, virRef, outputDir, index, mkdup, gz):
         indexRef(indexFile,ref)
 
     if index:
-        if mkdup:
-        ##generate mkdup alignment bash file
-            mkdupFile = scriptDir + "/mkdup.alignment.sh"
-            generate_mkdup_bash(mkdupFile,scriptDir)
+    ##generate mkdup alignment bash file
+        mkdupFile = scriptDir + "/mkdup.alignment.sh"
+        generate_mkdup_bash(mkdupFile,scriptDir)
 
-            with open(bashFile,'w') as output:
-                output.write(f'''#!/bin/bash
+        with open(bashFile,'w') as output:
+            output.write(f'''#!/bin/bash
 bash {indexFileHum};
 bash {indexFileVir};
 bash {indexFile};
 bash {alignmentFile};
 bash {indelFile};
-bash {mkdupFile};''')
-        else:
-            with open(bashFile,'w') as output:
-                output.write(f'''#!/bin/bash
-bash {indexFileHum};
-bash {indexFileVir};
-bash {indexFile};
-bash {alignmentFile};
-bash {indelFile};''')
-
+bash {mkdupFile};
+bash {rmInter};''')
     else:
-        if mkdup:
-            ##generate mkdup alignment bash file
-            mkdupFile = scriptDir + "/mkdup.alignment.sh"
-            generate_mkdup_bash(mkdupFile,scriptDir)
+        ##generate mkdup alignment bash file
+        mkdupFile = scriptDir + "/mkdup.alignment.sh"
+        generate_mkdup_bash(mkdupFile,scriptDir)
 
-            with open(bashFile,'w') as output:
-                output.write(f'''#!/bin/bash
+        with open(bashFile,'w') as output:
+            output.write(f'''#!/bin/bash
 bash {indexFile};
 bash {alignmentFile};
 bash {indelFile};
-bash {mkdupFile};''')
-        else:
-            with open(bashFile,'w') as output:
-                output.write(f'''#!/bin/bash
-bash {indexFile};
-bash {alignmentFile};
-bash {indelFile};''')
-
+bash {mkdupFile}
+bash {rmInter};''')
 
 
     #run scripts
