@@ -688,13 +688,13 @@ def filter_res(selectedAllContig,siteConfidence):
 # n: poly(n), n*d(A/T/C/G), will report low confidence if contig contains poly(n)
 def write_to_file(filteredSelectedContig,siteConfidence,out_dir,n):
     outputPath = f'{out_dir}/call_fusion_virus/'
-    if os.path.isfile(outputPath + 'HPVfusionPointContig.txt'):
-        os.system(f'rm {outputPath}/HPVfusionPointContig.txt')
+    if os.path.isfile(outputPath + 'VirusFusionPointContig.txt'):
+        os.system(f'rm {outputPath}/VirusFusionPointContig.txt')
 
     # extract contigSeq
     contigSeq = extractContigSeq(filteredSelectedContig,out_dir)
             
-    with open(outputPath + 'HPVfusionPointContig.txt','w') as output: 
+    with open(outputPath + 'VirusFusionPointContig.txt','w') as output: 
         output.write('contigName\tgenomeInsertionChromosome\tgenomeInsertionPoint\thpvInsertionPoint\tSiteConfidence\tContigConfidence\n')
     #     output.write('sampleName\tcontigName\tgenomeInsertionChromosome\tgenomeInsertionPoint\thpvInsertionPoint\tConfidence\n')
         for key,value in filteredSelectedContig.items():
